from re import T
from django.db import models

# Create your models here.


class Whatsapp(models.Model):
    name = models.CharField(max_length=100)
    phone = models.CharField(max_length=10)
    avatar = models.ImageField(upload_to='whatsappAvatar')
    draft = models.TextField(blank=True, null=True)

    def __str__(self) -> str:
        return self.name


from django.template import Library
from whatsapp_call.models import Whatsapp

register = Library()

@register.inclusion_tag('whatsapp_call/whatsapp_call_btn.html')
def whatsapp_widget():
    whatsapp = Whatsapp.objects.all()
    return {'wa_accounts': whatsapp}



# Generated by Django 4.1 on 2022-09-03 10:50

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Whatsapp',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('phone', models.CharField(max_length=10)),
                ('avatar', models.ImageField(upload_to='whatsappAvatar')),
            ],
        ),
    ]



# Generated by Django 4.1 on 2022-09-03 11:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('whatsapp_call', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='whatsapp',
            name='draft',
            field=models.TextField(blank=True, null=True),
        ),
    ]
